=================
collective.addons
=================

User documentation

.. toctree::
   :maxdepth: 2

   source/installation.rst
   source/configuration.rst
   source/addnewaddoncenter.rst
   source/addnewaddonproject.rst
   source/addnewaddonrelease.rst
   source/addnewaddonlinkedrelease.rst
   source/publishaddonrelease.rst
   source/publishaddonproject.rst
   source/messaging.rst

